@@ -1,7 +1,7 @@
 /* Control applet ("capplet") for the gnome-pilot calendar conduit,         */
 /* based on                                                                 */
 /* gpilotd control applet ('capplet') for use with the GNOME control center */
-/* $Id: calendar-conduit-control-applet.c,v 1.9 2000/01/08 04:44:57 vadim Exp $ */
+/* $Id: calendar-conduit-control-applet.c,v 1.12 2000/03/12 02:28:11 eskil Exp $ */
 
 #include <pwd.h>
 #include <sys/types.h>
@@ -12,9 +12,9 @@
 #include <config.h>
 #include <capplet-widget.h>
 
-#include <gpilotd/gpilotd-conduit-mgmt.h>
-#include <gpilotd/gpilotd-app.h>
-#include <gpilotd/gpilotd-app-dummy-callbacks.h>
+#include <libgpilotdCM/gnome-pilot-conduit-management.h>
+#include <libgpilotdCM/gnome-pilot-conduit-config.h>
+#include <gpilotd/gnome-pilot-client.h>
 
 #include "calendar-conduit.h"
 
@@ -29,7 +29,8 @@ GtkWidget *cfgOptionsWindow=NULL;
 GtkWidget *cfgStateWindow=NULL;
 GtkWidget *dialogWindow=NULL;
 
-GnomePilotConduitMgmt *conduit;
+GnomePilotConduitManagement *conduit;
+GnomePilotConduitConfig *conduit_config;
 
 static void doTrySettings(GtkWidget *widget, gpointer);
 static void doRevertSettings(GtkWidget *widget, gpointer);
@@ -42,6 +43,7 @@ GCalConduitCfg *origState = NULL;
 GCalConduitCfg *curState = NULL;
 
 gint pilotId;
+GnomePilotClient *gpc;
 CORBA_Environment ev;
 
 /* This array must be in the same order as enumerations
@@ -60,13 +62,14 @@ static void
 setSettings(GCalConduitCfg* conduitCfg)
 {
 	if(conduitCfg->sync_type!=GnomePilotConduitSyncTypeCustom)
-		gpilotd_conduit_mgmt_enable_with_first_sync(conduit,pilotId,
-							    conduitCfg->sync_type,
-							    conduitCfg->sync_type,
-							    TRUE);
+		gnome_pilot_conduit_config_enable_with_first_sync(conduit_config,
+								  
+								  conduitCfg->sync_type,
+								  conduitCfg->sync_type,
+								  TRUE);
 	else
-		gpilotd_conduit_mgmt_disable(conduit,pilotId);
-
+		gnome_pilot_conduit_config_disable(conduit_config);
+	
 	gcalconduit_save_configuration(conduitCfg);
 }
 
@@ -294,66 +297,92 @@ run_error_dialog(gchar *mesg,...) {
 }
 
 gint get_pilot_id_from_gpilotd() {
-	gint *pilots;
-	int i;
+	GList *pilots = NULL;
+	gint pilot;
+	int i,err;
   
 	i=0;
-	gpilotd_get_pilot_ids(&pilots);
-	if(pilots) {
-		while(pilots[i]!=-1) { g_message("pilot %d = \"%d\"",i,pilots[i]); i++; }
-		if(i==0) {
+	/* we don't worry about leaking here, so pilots isn't freed */
+	switch(err = gnome_pilot_client_get_pilots(gpc,&pilots)) {
+	case GPILOTD_OK: {
+		if(pilots) {
+			i=g_list_length(pilots);
+			if(i==0) {
+				run_error_dialog(_("No pilot configured, please choose the\n'Pilot Link Properties' capplet first."));
+				return -1;
+			} else {
+				gnome_pilot_client_get_pilot_id_by_name(gpc,
+									pilots->data, /* this is the first pilot */
+									&pilot);
+				if(i==1) {
+					return pilot;
+				}else {
+					g_message("too many pilots...");
+					/* need a choose here */
+					return pilot;
+				}
+			}
+		} else {
 			run_error_dialog(_("No pilot configured, please choose the\n'Pilot Link Properties' capplet first."));
 			return -1;
-		} else {
-			if(i==1) 
-				return pilots[0];
-			else {
-				g_message("too many pilots...");
-				return pilots[0];
-			}
-		}
-	} else {
-		run_error_dialog(_("No pilot configured, please choose the\n'Pilot Link Properties' capplet first."));
+		}    
+		break;
+	}
+	case GPILOTD_ERR_NOT_CONNECTED:
+		run_error_dialog(_("Not connected to the gnome-pilot daemon"));
 		return -1;
-	}    
+		break;
+	default:
+		g_warning("gnome_pilot_client_get_pilot_ids(...) = %d",err);
+		run_error_dialog(_("An error occured when trying to fetch\npilot list from the gnome-pilot daemon"));
+		return -1;
+		break;
+	}
+
 }
 
 int
 main( int argc, char *argv[] )
 {
-	/* we're a capplet */
+	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
+	textdomain (PACKAGE);
+
 	gnome_capplet_init ("calendar conduit control applet", NULL, argc, argv, 
 			    NULL,
 			    0, NULL);
 
-	/* get pilot name from gpilotd */
-	/* 1. initialize the gpilotd connection */
-	if (gpilotd_init(&argc,argv)!=0) {
-		run_error_dialog(_("Cannot initialze the GnomePilot Daemon"));
-		g_error(_("Cannot initialze the GnomePilot Daemon"));
-		return -1;
-	}
-    
-	/* 2 connect to gpilotd */
-	if (gpilotd_connect()!=0) {
-		run_error_dialog(_("Cannot connect to the GnomePilot Daemon"));
-		g_error(_("Cannot connect to the GnomePilot Daemon"));
-		return -1;
-	}
-    
+	/* Connect to gpilotd in order to retrieve pilot id's */
+	gpc = gnome_pilot_client_new();
+	gnome_pilot_client_connect_to_daemon(gpc);
+
+	/* get_pilot_id_from_gpilotd returns the first id of the pilots configures */
 	pilotId = get_pilot_id_from_gpilotd();
 	if(!pilotId) return -1;
 
-	/* put all code to set things up in here */
-	conduit = gpilotd_conduit_mgmt_new("calendar_conduit",pilotId);
-	gcalconduit_load_configuration(&origState,pilotId);
-	gpilotd_conduit_mgmt_get_sync_type(conduit,pilotId,&origState->sync_type);
+	/* Now make a conduit management object */
+	conduit = gnome_pilot_conduit_management_new("gnomecal",GNOME_PILOT_CONDUIT_MGMT_ID);
+	if (conduit==NULL) {
+		g_warning("Could not create object for conduit. The .conduit file may be missing.");
+		run_error_dialog(_("Could not create object for conduit.\n"
+				   "Perhaps the conduit isn't properly installed ?"));
+		return -1;
+	}
 
+	/* And now set up the conduit config object */
+	conduit_config = gnome_pilot_conduit_config_new(conduit,pilotId);
+
+	/* Load private configuration */
+	gcalconduit_load_configuration(&origState,pilotId);
+	
+	/* Get the sync type (if enabled) from the gpilotd config */
+	gnome_pilot_conduit_config_is_enabled(conduit_config,&origState->sync_type);
+
+	/* Remember the original settings */
 	curState = gcalconduit_dupe_configuration(origState);
     
+	/* Create the capplet */
 	pilot_capplet_setup();
 
-
 	/* done setting up, now run main loop */
 	capplet_gtk_main();
 	return 0;
