@@ -23,6 +23,8 @@ void ee_create_ae (GtkTable *table, char *str, CalendarAlarm *alarm, enum AlarmT
 		   int y, gboolean control_sens, GtkSignalFunc dirty_func);
 void ee_store_alarm (CalendarAlarm *alarm, enum AlarmType type);
 
+static gint ee_validity_check (EventEditor *ee);
+
 /* Note: do not i18n these strings, they are part of the vCalendar protocol */
 static char *class_names [] = { "PUBLIC", "PRIVATE", "CONFIDENTIAL" };
 
@@ -88,7 +90,7 @@ ee_check_all_day (EventEditor *ee)
 
 	ev_start = gnome_date_edit_get_date (GNOME_DATE_EDIT (ee->start_time));
 	ev_end   = gnome_date_edit_get_date (GNOME_DATE_EDIT (ee->end_time)); 
-	
+ 	
 	if (get_time_t_hour (ev_start) <= day_begin && get_time_t_hour (ev_end) >= day_end)
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (ee->general_allday), 1);
 	else
@@ -190,19 +192,16 @@ set_all_day (GtkToggleButton *toggle, EventEditor *ee)
 	struct tm tm;
 	time_t start_t;
 
-	start_t = gnome_date_edit_get_date (GNOME_DATE_EDIT (ee->start_time));
-	tm = *localtime (&start_t);
-	tm.tm_hour = day_begin;
-	tm.tm_min  = 0;
-	tm.tm_sec  = 0;
-	gnome_date_edit_set_time (GNOME_DATE_EDIT (ee->start_time), mktime (&tm));
-	
-	if (toggle->active)
+	if (toggle->active) {
+		start_t = gnome_date_edit_get_date (GNOME_DATE_EDIT (ee->start_time));
+		tm = *localtime (&start_t);
+		tm.tm_hour = day_begin;
+		tm.tm_min  = 0;
+		tm.tm_sec  = 0;
+		gnome_date_edit_set_time (GNOME_DATE_EDIT (ee->start_time), mktime (&tm));
 		tm.tm_hour = day_end;
-	else
-		tm.tm_hour++;
-	
-	gnome_date_edit_set_time (GNOME_DATE_EDIT (ee->end_time), mktime (&tm));
+		gnome_date_edit_set_time (GNOME_DATE_EDIT (ee->end_time), mktime (&tm));
+	}
 }
 
 /* Convenience function to create a properly-configured date editor widget */
@@ -746,6 +745,15 @@ ee_store_dlg_values_to_ical (EventEditor *ee)
 static void
 ee_ok (GtkWidget *widget, EventEditor *ee)
 {
+	if (!ee_validity_check (ee)) {
+		GtkWidget *mbox;
+		mbox = gnome_message_box_new (_("An event's end time must be later than its start time."),
+					      GNOME_MESSAGE_BOX_ERROR, GNOME_STOCK_BUTTON_OK, NULL);
+		gnome_dialog_set_parent (GNOME_DIALOG (mbox), GTK_WINDOW (ee));
+		gnome_dialog_run (GNOME_DIALOG (mbox));	
+		return;
+	}
+
 	ee_store_dlg_values_to_ical (ee);
 
 	if (ee->ical->new)
@@ -755,6 +763,7 @@ ee_ok (GtkWidget *widget, EventEditor *ee)
 
 	save_default_calendar (ee->gnome_cal);
 	ee->ical->new = 0;
+	gnome_dialog_close (GNOME_DIALOG (ee));
 }
 
 static void
@@ -764,9 +773,21 @@ ee_cancel (GtkWidget *widget, EventEditor *ee)
 		ical_object_destroy (ee->ical);
 		ee->ical = NULL;
 	}
-
+	
+	gnome_dialog_close (GNOME_DIALOG (ee));
 }
 
+static gint
+ee_validity_check (EventEditor *ee)
+{
+	time_t start, end;
+
+	start = gnome_date_edit_get_date (GNOME_DATE_EDIT (ee->start_time));
+	end   = gnome_date_edit_get_date (GNOME_DATE_EDIT (ee->end_time));
+
+	return (start < end);
+}
+	
 static void
 ee_create_buttons (EventEditor *ee)
 {
@@ -1185,21 +1206,22 @@ ee_rp_init_rule (EventEditor *ee)
 
 	/* Finish setting this up */
 
-	gtk_notebook_append_page (notebook, none, gtk_label_new (""));
-	gtk_notebook_append_page (notebook, daily, gtk_label_new (""));
-	gtk_notebook_append_page (notebook, weekly, gtk_label_new (""));
-	gtk_notebook_append_page (notebook, monthly, gtk_label_new (""));
-	gtk_notebook_append_page (notebook, yearly, gtk_label_new (""));
+	gtk_notebook_append_page (notebook, none, gtk_label_new ("None"));
+	gtk_notebook_append_page (notebook, daily, gtk_label_new ("Daily"));
+	gtk_notebook_append_page (notebook, weekly, gtk_label_new ("Weekly"));
+	gtk_notebook_append_page (notebook, monthly, gtk_label_new ("Monthly"));
+	gtk_notebook_append_page (notebook, yearly, gtk_label_new ("Yearly"));
 	gtk_notebook_set_show_tabs (notebook, FALSE);
 	gtk_notebook_set_show_border (notebook, FALSE);
 
+	gtk_widget_show_all (GTK_WIDGET (notebook));
 	gtk_notebook_set_page (notebook, page);
-
 	/* Attach to the main box */
 
 	gtk_box_pack_start (GTK_BOX (ee->recur_vbox), f, FALSE, FALSE, 0);
 }
 
+
 static void
 sensitize_on_toggle (GtkToggleButton *toggle, gpointer data)
 {
@@ -1302,7 +1324,7 @@ ee_rp_init_ending_date (EventEditor *ee)
 				gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (radio2), TRUE);
 			}
 		} else {
-			gnome_date_edit_set_time (GNOME_DATE_EDIT (ee->recur_ed_end_on), ee->ical->recur->enddate);
+			gnome_date_edit_set_time (GNOME_DATE_EDIT (ee->recur_ed_end_on), ee->ical->recur->enddate-86400);
 			gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (radio1), TRUE);
 		}
 	}
@@ -1500,7 +1522,7 @@ static void
 event_editor_init (EventEditor *ee)
 {
 	ee->ical = 0;
-	gnome_dialog_set_close (GNOME_DIALOG(ee), TRUE);
+	/*gnome_dialog_set_close (GNOME_DIALOG(ee), TRUE);*/
 }
 
 static void
