@@ -23,6 +23,7 @@
 #include "main.h"
 #include "timeutil.h"
 #include "corba-cal-factory.h"
+#include <libgnomeui/gnome-window-icon.h>
 
 #define COOKIE_USER_HOME_DIR ((char *) -1)
 
@@ -1031,7 +1032,7 @@ main(int argc, char *argv[])
 	process_dates ();
 	alarm_init ();
 	init_calendar ();
-
+	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-calendar.png");
 	/*
 	 * Load all of the calendars specifies in the command line with
 	 * the geometry specificied -if any-
