@@ -5,14 +5,15 @@
 #include <pwd.h>
 #include <sys/types.h>
 #include <signal.h>
+#include <ctype.h>
 #include <gnome.h>
 
 #include <config.h>
 #include <capplet-widget.h>
 
-#include <gpilotd/gpilotd-conduit-mgmt.h>
-#include <gpilotd/gpilotd-app.h>
-#include <gpilotd/gpilotd-app-dummy-callbacks.h>
+#include <libgpilotdCM/gnome-pilot-conduit-management.h>
+#include <libgpilotdCM/gnome-pilot-conduit-config.h>
+#include <gpilotd/gnome-pilot-client.h>
 
 #include "address-conduit.h"
 
@@ -27,7 +28,8 @@ GtkWidget *cfgOptionsWindow=NULL;
 GtkWidget *cfgStateWindow=NULL;
 GtkWidget *dialogWindow=NULL;
 
-GnomePilotConduitMgmt *conduit;
+GnomePilotConduitManagement *conduit;
+GnomePilotConduitConfig *conduit_config;
 
 ConduitCfg *origState = NULL;
 ConduitCfg *curState = NULL;
@@ -44,7 +46,82 @@ static void readOptionsCfg(GtkWidget *w, ConduitCfg *state);
 static void setOptionsCfg(GtkWidget *w, ConduitCfg *state);
 
 gint pilotId;
-CORBA_Environment ev;
+static GnomePilotClient *gpc;
+
+
+static void 
+load_configuration(ConduitCfg **c,guint32 pilotId) 
+{
+	gchar prefix[256];
+	g_return_if_fail(c!=NULL);
+	
+	g_snprintf(prefix,255,CONFIG_PREFIX,pilotId);
+ 
+	*c = g_new0(ConduitCfg,1);
+	gnome_config_push_prefix(prefix);
+	(*c)->sync_type = GnomePilotConduitSyncTypeCustom; /* this will be reset by capplet */
+	(*c)->filename = gnome_config_get_string("filename");
+	(*c)->open_secret = gnome_config_get_bool("open_secret=FALSE");
+	gnome_config_pop_prefix();
+	
+	if((*c)->filename==NULL) {
+		gchar *basedir=NULL;
+		gnome_pilot_client_get_pilot_base_dir_by_id(gpc,pilotId,&basedir);
+		(*c)->filename=g_strdup_printf("%s/Address.gcrd",basedir);
+		g_free(basedir);
+	} 
+	(*c)->pilotId = pilotId;
+}
+
+static void 
+save_configuration(ConduitCfg *c) 
+{
+	gchar prefix[256];
+
+	g_return_if_fail(c!=NULL);
+	g_snprintf(prefix,255,CONFIG_PREFIX,c->pilotId);
+	
+	gnome_config_push_prefix(prefix);
+	gnome_config_set_string("filename",c->filename);
+	gnome_config_set_bool("open_secret",c->open_secret);
+	gnome_config_pop_prefix();
+	
+	gnome_config_sync();
+	gnome_config_drop_all();
+}
+
+static void 
+copy_configuration(ConduitCfg *d, ConduitCfg *c)
+{
+	g_return_if_fail(c!=NULL);
+	g_return_if_fail(d!=NULL);
+	d->sync_type=c->sync_type;
+	if(d->filename) g_free(d->filename);
+	d->filename = g_strdup(c->filename);
+	d->open_secret = c->open_secret;
+	d->pilotId = c->pilotId;
+}
+
+static ConduitCfg*
+dupe_configuration(ConduitCfg *c) 
+{
+	ConduitCfg *d;
+	g_return_val_if_fail(c!=NULL,NULL);
+	d = g_new0(ConduitCfg,1);
+	copy_configuration(d,c);
+	return d;
+}
+
+
+/** this method frees all data from the conduit config */
+static void 
+destroy_configuration(ConduitCfg **c) 
+{
+	g_return_if_fail(c!=NULL);
+	if((*c)->filename) g_free((*c)->filename);
+	g_free(*c);
+	*c = NULL;
+}
 
 /* This array must be in the same order as enumerations
    in GnomePilotConduitSyncType as they are used as index.
@@ -62,12 +139,12 @@ static void
 setSettings(ConduitCfg* conduitCfg)
 {
 	if(conduitCfg->sync_type!=GnomePilotConduitSyncTypeCustom)
-		gpilotd_conduit_mgmt_enable_with_first_sync(conduit,pilotId,
-							    conduitCfg->sync_type,
-							    conduitCfg->sync_type,
-							    TRUE);
+		gnome_pilot_conduit_config_enable_with_first_sync(conduit_config,
+								  conduitCfg->sync_type,
+								  conduitCfg->sync_type,
+								  TRUE);
 	else
-		gpilotd_conduit_mgmt_disable(conduit,pilotId);
+		gnome_pilot_conduit_config_disable(conduit_config);
 
 	save_configuration(conduitCfg);
 }
@@ -133,7 +210,8 @@ statechange_cb(GtkEditable *editable, const gchar *text,
 		capplet_widget_state_changed(CAPPLET_WIDGET(capplet), TRUE);
 }
 
-void about_cb (GtkWidget *widget, gpointer data) 
+static void 
+about_cb (GtkWidget *widget, gpointer data) 
 {
 	GtkWidget *about;
 	const gchar *authors[] = {_("Vadim Strizhevsky <vadim@optonline.net>"),NULL};
@@ -353,7 +431,8 @@ pilot_capplet_setup(void)
 	gtk_widget_show_all(capplet);
 }
 
-void run_error_dialog(gchar *mesg,...) 
+static void 
+run_error_dialog(gchar *mesg,...) 
 {
 	char tmp[80];
 	va_list ap;
@@ -366,64 +445,77 @@ void run_error_dialog(gchar *mesg,...)
 }
 
 
-gint get_pilot_id_from_gpilotd() 
+static gint 
+get_pilot_id_from_gpilotd() 
 {
-	gint *pilots;
-	int i;
+	GList *pilots = NULL;
+	gint pilot=0;
+	int i,err;
   
 	i=0;
-	gpilotd_get_pilot_ids(&pilots);
-	if(pilots) {
-		while(pilots[i]!=-1) { g_message("pilot %d = \"%d\"",i,pilots[i]); i++; }
-		if(i==0) {
+	/* we don't worry about leaking here, so pilots isn't freed */
+	switch(err = gnome_pilot_client_get_pilots(gpc,&pilots)) {
+	case GPILOTD_OK: {
+		if(pilots) {
+			i=g_list_length(pilots);
+			if(i==0) {
+				run_error_dialog(_("No pilot configured, please choose the\n'Pilot Link Properties' capplet first."));
+				return -1;
+			} else {
+				gnome_pilot_client_get_pilot_id_by_name(gpc,
+									pilots->data, /* this is the first pilot */
+									&pilot);
+				if(i>1) {
+					g_message("too many pilots...");
+					/* need a choose here */
+				}
+				return pilot;
+			}
+		} else {
 			run_error_dialog(_("No pilot configured, please choose the\n'Pilot Link Properties' capplet first."));
 			return -1;
-		} else {
-			if(i==1) { 
-				return pilots[0];
-			} else {
-				g_message("too many pilots...");
-				return pilots[0];
-			}
-		}
-	} else {
-		run_error_dialog(_("No pilot configured, please choose the\n'Pilot Link Properties' capplet first."));
+		}    
+		break;
+	}
+	case GPILOTD_ERR_NOT_CONNECTED:
+		run_error_dialog(_("Not connected to the gnome-pilot daemon"));
 		return -1;
-	}  
+		break;
+	default:
+		g_warning("gnome_pilot_client_get_pilot_ids(...) = %d",err);
+		run_error_dialog(_("An error occured when trying to fetch\npilot list from the gnome-pilot daemon"));
+		return -1;
+		break;
+	}
 }
 
 int
 main( int argc, char *argv[] )
 {
-	/* we're a capplet */
-	gnome_capplet_init ("address conduit control applet", NULL, argc, argv, 
-			    NULL, 0, NULL);
+	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
+	textdomain (PACKAGE);
 
+	gnome_capplet_init ("calendar conduit control applet", NULL, argc, argv, 
+			    NULL,
+			    0, NULL);
 
-	/* get pilot name from gpilotd */
-	/* 1. initialize the gpilotd connection */
-	if (gpilotd_init(&argc,argv)!=0) {
-		run_error_dialog(_("Cannot initialze the GnomePilot Daemon"));
-		g_error(_("Cannot initialze the GnomePilot Daemon"));
-		return -1;
-	}
-    
-	/* 2 connect to gpilotd */
-	if (gpilotd_connect()!=0) {
-		run_error_dialog(_("Cannot connect to the GnomePilot Daemon"));
-		g_error(_("Cannot connect to the GnomePilot Daemon"));
-		return -1;
-	}
     
+	gpc = gnome_pilot_client_new();
+	gnome_pilot_client_connect_to_daemon(gpc);
 	pilotId = get_pilot_id_from_gpilotd();
 	if(!pilotId) return -1;
 
 	/* put all code to set things up in here */
-	conduit = gpilotd_conduit_mgmt_new("address_conduit",pilotId);
+	conduit = gnome_pilot_conduit_management_new("gnomecard",GNOME_PILOT_CONDUIT_MGMT_ID);
+	if (conduit==NULL) {
+		g_warning("Could not create object for conduit. The .conduit file may be missing.");
+		run_error_dialog(_("Could not create object for conduit.\n"
+				   "Perhaps the conduit isn't properly installed ?"));
+		return -1;
+	}
+	conduit_config = gnome_pilot_conduit_config_new(conduit,pilotId);
 	load_configuration(&origState,pilotId);
-
-	gpilotd_conduit_mgmt_get_sync_type(conduit,pilotId,&origState->sync_type);
-
+	gnome_pilot_conduit_config_is_enabled(conduit_config,&origState->sync_type);
 	curState = dupe_configuration(origState);
     
 	pilot_capplet_setup();
