@@ -1243,8 +1243,8 @@ extern void gnomecard_about(GtkWidget *widget, gpointer data)
 				   "drmike@redhat.com",
 				   NULL };
 	
-	about = gnome_about_new (_("GnomeCard"), NULL,
-				 "(C) 1997-1998 the Free Software Foundation",
+	about = gnome_about_new (_("GnomeCard"), VERSION,
+				 "(C) 1997-2000 the Free Software Foundation",
 				 authors,
 				 _("Electronic Business Card Manager"),
 				 NULL);
