@@ -31,7 +31,7 @@ gchar *email_type_name[] =
 	      { N_("America On-Line"), N_("Apple Link"), N_("AT&T"),
 		N_("CIS"), N_("e-World"), N_("Internet"), N_("IBM"),
 		N_("MCI"), N_("Power Share"), N_("Prodigy"), N_("TLX"),
-		N_("X.400"), NULL };
+		N_("X400"), NULL };
 
 static void emaillist_checkboxes_to_email_prop (EMailList *p, CardEMail *email)
 {
@@ -278,6 +278,7 @@ static void emaillist_up (GtkWidget *w, gpointer data)
 	g_ptr_array_index (p->email_array, p->row - 1) = temp;
 	p->row --;
 	emaillist_select_force (p, p->row);
+	gnome_property_box_changed(p->prop_box);
 }
 
 static void emaillist_down (GtkWidget *w, gpointer data)
@@ -296,6 +297,7 @@ static void emaillist_down (GtkWidget *w, gpointer data)
 	g_ptr_array_index (p->email_array, p->row + 1) = temp;
 	p->row ++;
 	emaillist_select_force (p, p->row);
+	gnome_property_box_changed(p->prop_box);
 }
 
 /* Functions for handling email numbers */
@@ -388,9 +390,9 @@ extern EMailList *emaillist_create_edit_page (Card *crd, GnomePropertyBox *box)
 	hbox = gtk_hbox_new(FALSE, GNOME_PAD_SMALL);
 	gtk_box_pack_start(GTK_BOX(p->the_vbox), hbox, 
 			   FALSE, FALSE, GNOME_PAD_SMALL);
-	w = gtk_label_new("URL:");
+	w = gtk_label_new("Web Page:");
 	gtk_box_pack_start(GTK_BOX(hbox), w, FALSE, FALSE, GNOME_PAD_SMALL);
-	p->url = w = my_gtk_entry_new(0, NULL);
+	p->url = w = my_gtk_entry_new(0, crd->url.str);
 	gtk_box_pack_start(GTK_BOX(hbox), w, TRUE, TRUE, GNOME_PAD_SMALL);
 	my_connect(w, "changed", box, &crd->url.prop, PROP_URL);
 	
@@ -407,7 +409,7 @@ extern EMailList *emaillist_create_edit_page (Card *crd, GnomePropertyBox *box)
 	gtk_container_add(GTK_CONTAINER(frame), hbox);
 	vbox = gtk_vbox_new(FALSE, GNOME_PAD_SMALL);
 	gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, GNOME_PAD_SMALL);
-	p->data = my_hbox_entry(vbox, _("Address:"), NULL);
+	p->data = my_hbox_entry(vbox, "Address:", NULL);
  	gtk_signal_connect(GTK_OBJECT(p->data), "changed",
 			   GTK_SIGNAL_FUNC(emaillist_data_changed), p);
 
@@ -422,7 +424,7 @@ extern EMailList *emaillist_create_edit_page (Card *crd, GnomePropertyBox *box)
 	group = NULL;
 	for (i = 0; i < 12; i++) {
 		p->type[i] = 
-		  gtk_radio_button_new_with_label(group, _(email_type_name[i]));
+		  gtk_radio_button_new_with_label(group, email_type_name[i]);
 		
 		gtk_signal_connect(GTK_OBJECT(p->type[i]), "toggled",
 				   GTK_SIGNAL_FUNC(emaillist_data_changed), p);
